"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_module_1 = require("./api-module");
class Notification extends api_module_1.default {
    async _send(userId, type, options = {}) {
        const result = await this.postReq(`user/${userId}/notification`, {
            type: type,
            message: options.message,
            details: options.details,
        });
        return result.data;
    }
    get send() {
        return {
            friendRequest: async (targetUser) => {
                const result = await this.postReq(`user/${targetUser}/notification`, {
                    type: 'friendrequest',
                });
                return result.data;
            },
            invite: async (targetUser, worldId, message = '') => {
                const result = await this.postReq(`user/${targetUser}/notification`, {
                    type: 'invite',
                    message: message,
                    details: JSON.stringify({
                        worldId: worldId
                    })
                });
                return result.data;
            },
            /**
             * @deprecated
             */
            halp: async (targetUser, worldId, message = '') => {
                // TODO わからん
                const result = await this.postReq(`user/${targetUser}/notification`, {
                    type: 'halp',
                    message: message,
                    details: JSON.stringify({
                    // ?
                    })
                });
                return result.data;
            },
            /**
             * @deprecated
             */
            voteToKick: async (targetUser) => {
                // TODO わからん
                const result = await this.postReq(`user/${targetUser}/notification`, {
                    type: 'votetokick',
                    details: JSON.stringify({
                    // ?
                    })
                });
                return result.data;
            },
            /**
             * @deprecated
             */
            all: async (targetUser) => {
                // TODO わからん
                const result = await this.postReq(`user/${targetUser}/notification`, {
                    type: 'all',
                    details: JSON.stringify({
                    // ?
                    })
                });
                return result.data;
            },
            /**
             * @deprecated
             */
            hidden: async (targetUser) => {
                // TODO わからん
                const result = await this.postReq(`user/${targetUser}/notification`, {
                    type: 'hidden',
                    details: JSON.stringify({
                    // ?
                    })
                });
                return result.data;
            },
            /**
             * @deprecated It seems that it can not be used yet.
             */
            async message() {
            },
        };
    }
    async markAsRead(notificationId) {
        const result = await this.putReq(`auth/user/notifications/${notificationId}/see`);
        return result.data;
    }
    async delete(notificationId) {
        const result = await this.putReq(`auth/user/notifications/${notificationId}/hide`);
        return result.data;
    }
    async getAll() {
        const result = await this.getReq(`auth/user/notifications`);
        return result.data;
    }
}
exports.default = Notification;
