"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_module_1 = require("./api-module");
class User extends api_module_1.default {
    async getUserInfo() {
        const result = await this.getReq('/auth/user');
        return result.data;
    }
    async updateUserInfo(params) {
        const result = await this.putReq(`/users/${this.userId}`, params);
        return result.data;
    }
    async getFriends(options = {}) {
        const result = await this.getReq('/auth/user/friends', options);
        return result.data;
    }
    async getFriendStatus(userId) {
        const result = await this.getReq(`/user/${userId}/friendStatus`);
        return result.data;
    }
    async sendFriendRequest(userId) {
        const result = await this.postReq(`/user/${userId}/friendRequest`);
        return result.data;
    }
    async unfriend(userId) {
        const result = await this.deleteReq(`/auth/user/friends/${userId}`);
        return result.data;
    }
    async acceptFriend(notificationId) {
        const result = await this.putReq(`/auth/user/notifications/${notificationId}/accept`);
        return result.data;
    }
    async getById(userId) {
        const result = await this.getReq(`/users/${userId}`);
        return result.data;
    }
    async getByName(username) {
        const result = await this.getReq(`/users/${username}/name`);
        return result.data;
    }
    get search() {
        return {
            all: async (options = {}) => {
                const result = await this.getReq(`/users`, options);
                return result.data;
            },
            /**
             * @deprecated 403 Error
             */
            active: async (options = {}) => {
                const result = await this.getReq(`/users/active`, options);
                return result.data;
            },
        };
    }
}
exports.default = User;
